# impulse
  A rewrite of PTMCMCSampler focusing on modularity

## Installation

  This package can be installed via pip: `pip install impulse_mcmc`

## Currently working:
  * Metropolis-Hastings sampling with adaptive jumps
  * Parallel tempering with adaptive temperature spacing (as in Vousden et al. 2016)
  * Vectorized likelihoods and priors

## Currently under development:
  * Resume function
